<?xml version="1.0"?>


<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:bibxml="http://bibtexml.sf.net/"
                version="1.0">

  <xsl:variable name="path">html</xsl:variable>

  <xsl:output method="xml" version="1.0" omit-xml-declaration="no"/>
  
  <xsl:template match="/">
    <xsl:document href="{$path}/data/index.xml">
      <bibxml:file>
        <xsl:call-template name="makeAuthorIndex"/>
        <xsl:call-template name="makeJournalIndex"/>
        <xsl:call-template name="makeKeywordsIndex"/>
        <xsl:call-template name="makeGroupIndex"/>
        <xsl:call-template name="makeYearIndex"/>

      </bibxml:file>
    </xsl:document>
  </xsl:template>


  <xsl:template name="makeAuthorIndex">
    <bibxml:author_index>
      <xsl:for-each select="///bibxml:author">
        <xsl:sort/>
        <xsl:if test="not(. = following::*)">
          <bibxml:author>
            <xsl:value-of select="."/> 
          </bibxml:author>
        </xsl:if>
      </xsl:for-each>
    </bibxml:author_index>
  </xsl:template>


  <xsl:template name="makeJournalIndex">
    <bibxml:journal_index>
      <xsl:for-each select="///bibxml:journal">
        <xsl:sort/>
        <xsl:if test="not(. = following::*)">
          <bibxml:journal>
            <xsl:value-of select="."/> 
          </bibxml:journal>
        </xsl:if>
      </xsl:for-each>
    </bibxml:journal_index>
  </xsl:template>


  <xsl:template name="makeKeywordsIndex">
    <bibxml:keywords_index>
      <xsl:for-each select="///bibxml:keywords">
        <xsl:sort/>
        <xsl:if test="not(. = following::*)">
          <bibxml:keywords>
            <xsl:if test="not(contains(.,'*'))">
               <xsl:value-of select="."/>
            </xsl:if>
            <xsl:if test="contains(.,'*')">
               <xsl:value-of select="concat(substring-before(.,'*'),substring-after(.,'*'))"/>            </xsl:if>
          </bibxml:keywords>
        </xsl:if>
      </xsl:for-each>
    </bibxml:keywords_index>
  </xsl:template>


  <xsl:template name="makeYearIndex">
    <bibxml:year_index>
      <xsl:for-each select="///bibxml:year">
        <xsl:sort order="descending"/>
        <xsl:if test="not(. = following::*)">
          <bibxml:year>
            <xsl:value-of select="."/> 
          </bibxml:year>
        </xsl:if>
      </xsl:for-each>
    </bibxml:year_index>
  </xsl:template>

  <xsl:template name="makeGroupIndex">
    <bibxml:group_index>
      <xsl:for-each select="///bibxml:group">
        <xsl:sort/>
        <xsl:if test="not(. = following::*)">
          <bibxml:group>
            <xsl:value-of select="."/> 
          </bibxml:group>
        </xsl:if>
      </xsl:for-each>
    </bibxml:group_index>
  </xsl:template>


</xsl:stylesheet>
